library run_file.transformer;

import 'dart:async';
import 'package:barback/barback.dart';
import 'package:path/path.dart';
import 'dart:io';

/// Transformer used by `pub build` and to run .bat files.
class RunFileTransformer extends Transformer {
  final BarbackSettings settings;
  final TransformerOptions options;

  RunFileTransformer(BarbackSettings settings) :
    settings = settings,
    options = new TransformerOptions.parse(settings.configuration);

  RunFileTransformer.asPlugin(BarbackSettings settings) :
    this(settings);

  Future<bool> isPrimary(AssetId input) {
    var extension = posix.extension(input.path);
    var primary = extension == '.bat';
    if (options.executable != null) {
      primary = posix.basename(input.path) == posix.basename(options.executable);
    }
    
    if (primary) {
      print('isPrimary()');
      print('options.executable' + options.executable);
      print('input.path=' + input.path);
    }

    return new Future.value(primary);
  }

  Future apply(Transform transform) {
    String path = options.executable;//transform.primaryInput.id.path;

    transform.consumePrimary();

    print('apply()' + ' path=' + path);
    return Process.run(path, []).then((ProcessResult result) {
      return;
    }).catchError((ProcessException e) {
      print(e.toString());
    });
  }
}

class TransformerOptions {
  final String executable;

  TransformerOptions({String this.executable});

  factory TransformerOptions.parse(Map configuration) {
    config(key, defaultValue) {
      var value = configuration[key];
      return value != null ? value : defaultValue;
    }

    return new TransformerOptions(
        executable: config("executable", ""));
  }
}
